@@ -31,7 +31,7 @@
 
 from __future__ import annotations
 
-from typing import List, Optional, Union
+from typing import Callable, List, Optional, Union
 
 from bokeh.embed import file_html as HTMLofBackendContent  # noqa
 from bokeh.layouts import LayoutDOM as backend_content_t  # noqa
@@ -43,11 +43,7 @@ from bokeh.plotting.figure import Figure as backend_frame_t  # noqa
 from bokeh.resources import INLINE  # noqa
 
 from babelplot.backend.brick.html import Show as BackendShow
-from babelplot.backend.specification.plot import (
-    TranslatedArguments,
-    UNAVAILABLE_for_this_DIM,
-    plot_e,
-)
+from babelplot.backend.specification.plot import UNAVAILABLE_for_this_DIM, plot_e
 from babelplot.type.dimension import dim_e
 from babelplot.type.figure import figure_t as base_figure_t
 from babelplot.type.frame import frame_t as base_frame_t
@@ -76,27 +72,18 @@ def _NewFrame(
 def _NewPlot(
     frame: frame_t,
     type_: Union[str, plot_e, type(backend_plot_t)],
+    plot_function: Optional[Callable],
     *args,
     title: str = None,  # If _, then it is swallowed by kwargs!
     **kwargs,
 ) -> tuple[backend_plot_t, type(backend_plot_t)]:
     """"""
-    if isinstance(type_, str):
-        if plot_e.IsValid(type_):
-            plot_type = plot_e.NewFromName(type_)
-            plot_function = plot_type.BackendPlot(frame.frame_dim, NAME, PLOTS)
-        elif hasattr(backend_frame_t, type_):
+    if plot_function is None:
+        if hasattr(backend_frame_t, type_):
             plot_function = getattr(backend_frame_t, type_)
         else:
             raise TypeError(f"{type_}: Unknown {NAME} graph object.")
-    elif isinstance(type_, plot_e):
-        plot_function = type_.BackendPlot(frame.frame_dim, NAME, PLOTS)
-    else:
-        plot_function = type_
 
-    args, kwargs = TranslatedArguments(
-        plot_function, args, kwargs, PARAMETERS_TRANSLATIONS
-    )
     output = plot_function(frame.backend, *args, **kwargs)
 
     return output, plot_function
@@ -152,6 +139,6 @@ PLOTS = {
 }
 
 
-PARAMETERS_TRANSLATIONS = {
+TRANSLATIONS = {
     "color_face": "fill_color",
 }
