@@ -31,15 +31,15 @@
 
 from __future__ import annotations
 
-from typing import Union
+from typing import Callable, Optional, Union
 
 import plotly.graph_objects as plly  # noqa
 from plotly.basedatatypes import BasePlotlyType as backend_plot_t  # noqa
 from plotly.graph_objects import Figure as backend_content_t  # noqa
-from plotly.graph_objects import Figure as backend_frame_t  # noqa
+from plotly.graph_objects import Figure as backend_frame_t
 
 from babelplot.backend.brick.html import Show as BackendShow
-from babelplot.backend.specification.plot import plot_e  # , TranslatedArguments
+from babelplot.backend.specification.plot import plot_e
 from babelplot.type.dimension import dim_e
 from babelplot.type.figure import figure_t as base_figure_t
 from babelplot.type.frame import frame_t as base_frame_t
@@ -76,26 +76,22 @@ def _NewFrame(
 def _NewPlot(
     frame: frame_t,
     type_: Union[str, plot_e, type(backend_plot_t)],
+    plot_function: Optional[Callable],
     *args,
     title: str = None,  # If _, then it is swallowed by kwargs!
     **kwargs,
 ) -> tuple[backend_plot_t, type(backend_plot_t)]:
     """"""
-    if isinstance(type_, str):
-        if plot_e.IsValid(type_):
-            type_ = plot_e.NewFromName(type_).BackendPlot(frame.frame_dim, NAME, PLOTS)
-        elif hasattr(plly, type_):
-            type_ = getattr(plly, type_)
+    if plot_function is None:
+        if hasattr(plly, type_):
+            plot_function = getattr(plly, type_)
         else:
             raise TypeError(f"{type_}: Unknown {NAME} graph object.")
-    elif isinstance(type_, plot_e):
-        type_ = type_.BackendPlot(frame.frame_dim, NAME, PLOTS)
 
-    # args, kwargs = TranslatedArguments(args, kwargs, PARAMETERS_TRANSLATIONS)
-    output = type_(*args, **kwargs)
+    output = plot_function(*args, **kwargs)
     frame.backend.add_trace(output)
 
-    return output, type_
+    return output, plot_function
 
 
 def _HTMLofContent(_, content: backend_content_t, *__, **___) -> str:
@@ -125,4 +121,4 @@ figure_t: base_figure_t = type(
 PLOTS = {}
 
 
-# PARAMETERS_TRANSLATIONS = {}
+TRANSLATIONS = {}
