@@ -60,6 +60,7 @@ figure = NewBabelPlotFigure()
 frame = figure.AddFrame()
 plot = frame.AddPlot("scatter", delta1[:-1], delta1[1:], size=volume, color=close, alpha=0.5)
 plot.SetProperty("marker", "+")
+frame.backend.grid(True)
 
 frame_3d = figure.AddFrame(dim="xyz", col=1)
 frame_3d.AddPlot(
@@ -67,8 +68,8 @@ frame_3d.AddPlot(
 )
 
 frame_3d = figure.AddFrame(dim="xyz", col=2)
-frame_3d.AddPlot("surface", X, Y, Z, cmap=cm.cool_r, linewidth=0, antialiased=False)
-frame_3d.SetProperties(
+frame_3d.AddPlot("elevation", Z, x=X, y=Y, cmap=cm.cool_r, linewidth=0, antialiased=False)
+frame_3d.SetProperty(
     "title",
     "Volume and percent change",
     "xlabel",
@@ -76,7 +77,12 @@ frame_3d.SetProperties(
     "ylabel",
     r"$\Delta_{i+1}$",
 )
-frame.backend.grid(True)
+
+frame = figure.AddFrame(col=3)
+frame.AddPlot("isoset", Z, 0.8*nmpy.amax(Z))
+
+frame = figure.AddFrame(col=4)
+frame.AddPlot("image", Z)
 
 
 figure.backend.tight_layout()
